==> gpsjinni_0.8.20100702-1.tar.gz: gpsjinni-0.8.20100702/src/Configuration.cpp <==
/*
  TimerJinni - A general timing application
  Copyright (C) 2009  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Configuration.h"

#include <algorithm>
#include <iostream>
#include <sstream>

#include <Lum/Base/Path.h>
#include <Lum/Base/String.h>

#include <Lum/Config/Config.h>

Lum::Model::SizeTRef   unitMode(new Lum::Model::SizeT(1));
Lum::Model::BooleanRef prohibitScreenBlanking(new Lum::Model::Boolean(false));

bool LoadConfig()
{
  Lum::Config::Node      *top;
  Lum::Config::ErrorList errors;
  Lum::Base::Path        path(Lum::Base::Path::GetApplicationConfigPath());

  top=Lum::Config::LoadConfigFromXMLFile(path.GetPath(),errors);

  if (top==NULL) {
    return false;
  }

  if (top->GetName()!=L"GPSJinni") {
    std::cerr << "'" << Lum::Base::WStringToString(path.GetPath()) << "' is a valid config file!" << std::endl;
    delete top;
    return false;
  }

  size_t unitMode;
  size_t prohibitScreenBlanking;
  
  if (top->GetAttribute(L"unitMode",unitMode)) {
    ::unitMode->Set(unitMode);
  }

  if (top->GetAttribute(L"prohibitScreenBlanking",prohibitScreenBlanking)) {
    ::prohibitScreenBlanking->Set(prohibitScreenBlanking);
  }

  delete top;

  return true;
}

bool SaveConfig()
{
  Lum::Config::Node *top;
  Lum::Base::Path   path(Lum::Base::Path::GetApplicationConfigPath());
  std::wstring      config;
  bool              res;

  top=new Lum::Config::Node();
  top->SetName(L"GPSJinni");

  Lum::Base::Status status;

  status=path.CreateDirRecursive();

  if (!status) {
    std::cerr << "Cannot create config directory '" << Lum::Base::WStringToString(path.GetDir()) << "': " << Lum::Base::WStringToString(status.GetDescription()) << std::endl;
    return false;
  }

  top->SetAttribute(L"prohibitScreenBlanking",prohibitScreenBlanking->Get());
  top->SetAttribute(L"unitMode",unitMode->Get());

  res=Lum::Config::SaveConfigToXMLFile(path.GetPath(),top);

  delete top;

  return res;
}

==> gpsjinni_0.9.20101005-1.tar.gz: gpsjinni-0.9.20101005/src/Configuration.cpp <==
/*
  TimerJinni - A general timing application
  Copyright (C) 2009  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "Configuration.h"

#include <algorithm>
#include <iostream>
#include <sstream>

#include <Lum/Base/Path.h>
#include <Lum/Base/String.h>

#include <Lum/Config/Config.h>

Lum::Model::SizeTRef   unitMode(new Lum::Model::SizeT(1));
Lum::Model::BooleanRef prohibitScreenBlanking(new Lum::Model::Boolean(false));
Lum::Model::BooleanRef compassShowCourseDirection(new Lum::Model::Boolean(false));
Lum::Model::BooleanRef compassShowRawGPSDirection(new Lum::Model::Boolean(false));

bool LoadConfig()
{
  Lum::Config::Node      *top;
  Lum::Config::ErrorList errors;
  Lum::Base::Path        path(Lum::Base::Path::GetApplicationConfigPath());

  top=Lum::Config::LoadConfigFromXMLFile(path.GetPath(),errors);

  if (top==NULL) {
    // TODO: convert errors to text
    std::cerr << "LoadConfig from '" << Lum::Base::WStringToString(path.GetPath()) << "': " << "ERROR" << std::endl;
    return false;
  }

  if (top->GetName()!=L"GPSJinni") {
    std::cerr << "LoadConfig from '" << Lum::Base::WStringToString(path.GetPath()) << "': not a GPSJinni config file!" << std::endl;
    delete top;
    return false;
  }

  size_t settingsLoaded = 0;
  size_t unitMode;
  bool prohibitScreenBlanking;
  bool compassShowCourseDirection;
  bool compassShowRawGPSDirection;
  
  if (top->GetAttribute(L"unitMode",unitMode)) {
    ::unitMode->Set(unitMode);
    settingsLoaded++;
  }

  if (top->GetAttribute(L"prohibitScreenBlanking",prohibitScreenBlanking)) {
    ::prohibitScreenBlanking->Set(prohibitScreenBlanking);
    settingsLoaded++;
  }

  if (top->GetAttribute(L"compassShowCourseDirection",compassShowCourseDirection)) {
    ::compassShowCourseDirection->Set(compassShowCourseDirection);
    settingsLoaded++;
  }

  if (top->GetAttribute(L"compassShowRawGPSDirection",compassShowRawGPSDirection)) {
    ::compassShowRawGPSDirection->Set(compassShowRawGPSDirection);
    settingsLoaded++;
  }
  std::cerr << "LoadConfig from '" << Lum::Base::WStringToString(path.GetPath()) << "': "
            << settingsLoaded << " settings loaded" << std::endl;

  delete top;

  return true;
}

bool SaveConfig()
{
  Lum::Config::Node *top;
  Lum::Base::Path   path(Lum::Base::Path::GetApplicationConfigPath());
  std::wstring      config;
  bool              res;

  top=new Lum::Config::Node();
  top->SetName(L"GPSJinni");

  Lum::Base::Status status;

  status=path.CreateDirRecursive();

  if (!status) {
    std::cerr << "Cannot create config directory '" << Lum::Base::WStringToString(path.GetDir()) << "': " << Lum::Base::WStringToString(status.GetDescription()) << std::endl;
    return false;
  }

  top->SetAttribute(L"prohibitScreenBlanking",prohibitScreenBlanking->Get());
  top->SetAttribute(L"unitMode",unitMode->Get());
  top->SetAttribute(L"compassShowCourseDirection",compassShowCourseDirection->Get());
  top->SetAttribute(L"compassShowRawGPSDirection",compassShowRawGPSDirection->Get());

  res=Lum::Config::SaveConfigToXMLFile(path.GetPath(),top);
  
  std::cerr << "SaveConfig to '" << Lum::Base::WStringToString(path.GetPath()) << "': " << (res ? "OK" : "ERROR") << std::endl;

  delete top;

  return res;
}
